Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(586)

Unified Diff: chrome/installer/util/util_constants.h

Issue 18732: Wire the eula and the dialog display code... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 11 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/installer/util/util_constants.h
===================================================================
--- chrome/installer/util/util_constants.h (revision 8439)
+++ chrome/installer/util/util_constants.h (working copy)
@@ -33,7 +33,9 @@
UNINSTALL_CANCELLED, // User cancelled Chrome uninstallation
UNKNOWN_STATUS, // Unknown status (this should never happen)
RENAME_SUCCESSFUL, // Rename of new_chrome.exe to chrome.exe worked
- RENAME_FAILED // Rename of new_chrome.exe failed
+ RENAME_FAILED, // Rename of new_chrome.exe failed
+ EULA_REJECTED, // EULA dialog was not accepted by user.
+ EULA_ACCEPTED // EULA dialog was accepted by user.
};
// These are distibution related install options specified through command
@@ -74,6 +76,7 @@
extern const wchar_t kSystemLevel[];
extern const wchar_t kUninstall[];
extern const wchar_t kVerboseLogging[];
+extern const wchar_t kShowEula[];
} // namespace switches
extern const wchar_t kInstallBinaryDir[];

Powered by Google App Engine
This is Rietveld 408576698